Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(897)

Unified Diff: ui/views/controls/button/custom_button.cc

Issue 23531053: ui/base/animation -> ui/gfx/animation (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Merge 2 trunk Created 7 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/views/controls/button/custom_button.h ('k') | ui/views/controls/button/image_button.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/views/controls/button/custom_button.cc
diff --git a/ui/views/controls/button/custom_button.cc b/ui/views/controls/button/custom_button.cc
index f8e8b58d2cff6cf0f026f56ca017e52475d93f39..17ea8df93bf8f1af5ce209f5e092a04c5cf7ac85 100644
--- a/ui/views/controls/button/custom_button.cc
+++ b/ui/views/controls/button/custom_button.cc
@@ -5,9 +5,9 @@
#include "ui/views/controls/button/custom_button.h"
#include "ui/base/accessibility/accessible_view_state.h"
-#include "ui/base/animation/throb_animation.h"
#include "ui/base/events/event.h"
#include "ui/base/keycodes/keyboard_codes.h"
+#include "ui/gfx/animation/throb_animation.h"
#include "ui/gfx/screen.h"
#include "ui/views/widget/widget.h"
@@ -277,9 +277,9 @@ void CustomButton::VisibilityChanged(View* starting_from, bool visible) {
}
////////////////////////////////////////////////////////////////////////////////
-// CustomButton, ui::AnimationDelegate implementation:
+// CustomButton, gfx::AnimationDelegate implementation:
-void CustomButton::AnimationProgressed(const ui::Animation* animation) {
+void CustomButton::AnimationProgressed(const gfx::Animation* animation) {
SchedulePaint();
}
@@ -293,7 +293,7 @@ CustomButton::CustomButton(ButtonListener* listener)
is_throbbing_(false),
triggerable_event_flags_(ui::EF_LEFT_MOUSE_BUTTON),
request_focus_on_press_(true) {
- hover_animation_.reset(new ui::ThrobAnimation(this));
+ hover_animation_.reset(new gfx::ThrobAnimation(this));
hover_animation_->SetSlideDuration(kHoverFadeDurationMs);
}
« no previous file with comments | « ui/views/controls/button/custom_button.h ('k') | ui/views/controls/button/image_button.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698